//+------------------------------------------------------------------+
//|                                                IncludeTest01.mqh |
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+

#property copyright "000"

#include <stdlib.mqh>


int OpenBuyOrder(string argSymbol, double argLotSize, double argSlippage, double argMagicNumber, string argComment = "Buy Order")
	{
		while(IsTradeContextBusy()) Sleep(10);

		// Place Buy Order
		int Ticket = OrderSend(argSymbol,OP_BUY,argLotSize,MarketInfo(argSymbol,MODE_ASK),argSlippage,0,0,argComment,argMagicNumber,0,Green);

		// Error Handling
		if(Ticket == -1)
			{
				int ErrorCode = GetLastError();
				string ErrDesc = ErrorDescription(ErrorCode);

				string ErrAlert = StringConcatenate("Open Buy Order - Error	",ErrorCode,": ",ErrDesc);
				Alert(ErrAlert);

				string ErrLog = StringConcatenate("Bid: ",MarketInfo(argSymbol,MODE_BID)," Ask: ",MarketInfo(argSymbol,MODE_ASK)," Lots: ",argLotSize);
				Print(ErrLog);
			}
		
		return(Ticket);
	}     
	
	
int OpenSellOrder(string argSymbol, double argLotSize, double argSlippage, double argMagicNumber, string argComment = "Sell Order")
	{
		while(IsTradeContextBusy()) Sleep(10);

		// Place Sell Order
		int Ticket = OrderSend(argSymbol,OP_SELL,argLotSize,MarketInfo(argSymbol,MODE_BID),argSlippage,0,0,argComment,argMagicNumber,0,Red);

		// Error Handling
		if(Ticket == -1)
			{
				int ErrorCode = GetLastError();
				string ErrDesc = ErrorDescription(ErrorCode);

				string ErrAlert = StringConcatenate("Open Sell Order - Error ",ErrorCode,": ",ErrDesc);
				Alert(ErrAlert);

				string ErrLog = StringConcatenate("Bid: ",MarketInfo(argSymbol,MODE_BID)," Ask: ",MarketInfo(argSymbol,MODE_ASK)," Lots: ",argLotSize);
				Print(ErrLog);
			}

		return(Ticket);
	}     
	
	
double PipPoint(string Currency)
	{
		int CalcDigits = MarketInfo(Currency,MODE_DIGITS);
		if(CalcDigits == 2 || CalcDigits == 3) double CalcPoint = 0.01;
		else if(CalcDigits == 4 || CalcDigits == 5) CalcPoint = 0.0001;
		return(CalcPoint);
	}


int GetSlippage(string Currency, int SlippagePips)
	{
		int CalcDigits = MarketInfo(Currency,MODE_DIGITS);
		if(CalcDigits == 2 || CalcDigits == 4) double CalcSlippage = SlippagePips;
		else if(CalcDigits == 3 || CalcDigits == 5) CalcSlippage = SlippagePips * 10;
		return(CalcSlippage);
	}
	
	
int BuyMarketCount(string argSymbol, int argMagicNumber)
	{
		int OrderCount;
		for(int Counter = 0; Counter <= OrdersTotal()-1; Counter++)
			{
				OrderSelect(Counter,SELECT_BY_POS);
				if(OrderMagicNumber() == argMagicNumber && OrderSymbol() == argSymbol && OrderType() == OP_BUY)
					{
						OrderCount++;
					}
			}
		return(OrderCount);
	}
	
	
int SellMarketCount(string argSymbol, int argMagicNumber)
	{
		int OrderCount;
		for(int Counter = 0; Counter <= OrdersTotal()-1; Counter++)
			{
				OrderSelect(Counter,SELECT_BY_POS);
				if(OrderMagicNumber() == argMagicNumber && OrderSymbol() == argSymbol && OrderType() == OP_SELL)
					{
						OrderCount++;
					}
			}
		return(OrderCount);
	}
	
	
void CloseAllBuyOrders(string argSymbol, int argMagicNumber, int argSlippage)
	{
		for(int Counter = 0; Counter <= OrdersTotal()-1; Counter++)
			{
				OrderSelect(Counter,SELECT_BY_POS);

				if(OrderMagicNumber() == argMagicNumber && OrderSymbol() == argSymbol && OrderType() == OP_BUY) 
					{
						// Close Order
						int CloseTicket = OrderTicket();
						double CloseLots = OrderLots();

						while(IsTradeContextBusy()) Sleep(10);

						double ClosePrice = MarketInfo(argSymbol,MODE_BID);

						bool Closed = OrderClose(CloseTicket,CloseLots,ClosePrice,argSlippage,Red);

						// Error Handling
						if(Closed == false)
							{
								int ErrorCode = GetLastError();
								string ErrDesc = ErrorDescription(ErrorCode);

								string ErrAlert = StringConcatenate("Close All Buy Orders - Error ",ErrorCode,": ",ErrDesc);
								Alert(ErrAlert);

								string ErrLog = StringConcatenate("Bid: ",MarketInfo(argSymbol,MODE_BID)," Ticket: ",CloseTicket," Price: ",ClosePrice);
								Print(ErrLog);
							}
						else Counter--;
					}
			}
	}
	
	

void CloseAllSellOrders(string argSymbol, int argMagicNumber, int argSlippage)
	{
		for(int Counter = 0; Counter <= OrdersTotal()-1; Counter++)
			{
				OrderSelect(Counter,SELECT_BY_POS);

				if(OrderMagicNumber() == argMagicNumber && OrderSymbol() == argSymbol && OrderType() == OP_SELL) 
					{
						// Close Order
						int CloseTicket = OrderTicket();
						double CloseLots = OrderLots();

						while(IsTradeContextBusy()) Sleep(10);

						double ClosePrice = MarketInfo(argSymbol,MODE_ASK);

						bool Closed = OrderClose(CloseTicket,CloseLots,ClosePrice,argSlippage,Red);

						// Error Handling
						if(Closed == false)
							{
								int ErrorCode = GetLastError();
								string ErrDesc = ErrorDescription(ErrorCode);

								string ErrAlert = StringConcatenate("Close All Sell Orders - Error ",ErrorCode,": ",ErrDesc);
								Alert(ErrAlert);

								string ErrLog = StringConcatenate("Ask: ",MarketInfo(argSymbol,MODE_ASK)," Ticket: ",CloseTicket," Price: ",ClosePrice);
									Print(ErrLog);
							}
						else Counter--;
					}
			}
	}